@@ -1,5 +1,6 @@
 import asyncio
 from enum import Enum
+from sys import platform
 from typing import Optional
 
 from rich.traceback import install
@@ -9,7 +10,21 @@ from weather_command._builder import show_current, show_daily, show_hourly
 from weather_command._cache import Cache
 from weather_command._tui import WeatherApp
 
-__version__ = "3.2.0"
+
+def _is_uvloop_platform() -> bool:
+    if platform != "win32":
+        return True  # pragma: no cover
+
+    return False  # pragma: no cover
+
+
+if _is_uvloop_platform():
+    try:
+        import uvloop
+    except ImportError:
+        pass
+
+__version__ = "3.2.2"
 
 install()
 app = Typer()
@@ -26,12 +41,6 @@ class How(str, Enum):
     ZIP = "zip"
 
 
-def version_callback(value: bool) -> None:
-    if value:
-        echo(__version__)
-        raise Exit()
-
-
 @app.command()
 def cli(
     how: How = Argument(
@@ -78,6 +87,12 @@ def cli(
 ) -> None:
     """Run in CLI mode."""
 
+    if _is_uvloop_platform():
+        try:
+            uvloop.install()
+        except NameError:
+            pass
+
     if clear_cache:
         cache = Cache()
         cache.clear()
